@@ -9,6 +9,7 @@ from contextlib import contextmanager
 from dataclasses import dataclass
 
 import tkinter as tk
+import tkinter.font
 from tkinter import ttk
 import tkinter.simpledialog  # Implemented in newer typshed versions
 
@@ -112,6 +113,17 @@ class RootWindow(tk.Tk, mixin.ContainerWidget):
         # Not applicable to root window
         raise NotImplementedError
 
+    def gbinding(self, *args, immediate: bool = True, **kwargs) -> model.BindingGlobal:
+        '''Create a `model.BindingGlobal` for this application.
+
+        Args:
+            immediate: Passed to the upstream object, default to enabling the
+                binding on creation. This is the opposite from upstream.
+
+        All arguments are passed to the `model.BindingGlobal` object.
+        '''
+        return model.BindingGlobal(self, *args, immediate=immediate, **kwargs)
+
 
 class FrameUnlabelled(ttk.Frame, mixin.ContainerWidget):
     '''A simple frame to hold other widgets, visually invisible.
@@ -705,14 +717,16 @@ class EntryMultiline(tk.Text, mixin.SingleWidget):
     class Style(model.WStyle):
         '''`EntryMultiline` style object.
 
-        These are the colours:
+        These are the settings:
 
         Args:
+            font_base: Base Font name, for all the widget.
             colour_bg_on: Widget background, when enabled.
             colour_bg_off: Widget background, when disabled.
             colour_link_normal: Hyperlink foreground colour, normal links.
             colour_link_visited: Hyperlink foreground colour, visited links.
         '''
+        font_base: str = 'TkTextFont'  # This font should be used for user text in entry widgets, listboxes etc.
         colour_bg_on: str = 'white'
         colour_bg_off: str = 'lightgrey'
         colour_link_normal: str = 'blue'
@@ -724,6 +738,7 @@ class EntryMultiline(tk.Text, mixin.SingleWidget):
         self.wstyle = style
         self.init_single(variable)
         kwargs.pop('state', None)  # Support only readonly state
+        kwargs['font'] = style.font_base  # Override the base font
         super().__init__(parent, **kwargs)  # tk.Entry
         readonly = True  # Support only readonly state, for now...
         # GUI State Tracker
@@ -849,19 +864,44 @@ class EntryMultiline(tk.Text, mixin.SingleWidget):
         self._bindings_tag[name] = model.BindingTag(self, tag, sequence, *args, immediate=immediate, **kwargs)
         return self._bindings_tag[name]
 
+    # TODO: use an `lru_cache`?
+    def _font(self, fontbase: typing.Optional[tk.font.Font] = None,
+              *,
+              size: typing.Optional[int] = None,
+              bold: typing.Optional[bool] = None,
+              italic: typing.Optional[bool] = None,
+              ):
+        fontbase = fontbase or tk.font.nametofont(self.wstyle.font_base)
+        # Start from the base font options
+        options = fontbase.actual()
+        if size:
+            options['size'] = size
+        if bold is True:
+            options['weight'] = tk.font.BOLD
+        if italic is True:
+            options['slant'] = tk.font.ITALIC
+        return tk.font.Font(**options)
+
     def _style_a(self, tag: str = 'a', *, visited: bool) -> None:
         fg = self.wstyle.colour_link_visited if visited else self.wstyle.colour_link_normal
         self.tag_configure(tag, foreground=fg, underline=True)
 
-    def style_reset(self, event=None, *, a: bool = True) -> None:
+    def style_reset(self, event=None, *, a: bool = True, b: bool = True, i: bool = True) -> None:
         '''Reset the style to the original.
 
         Args:
             a: Reset ``a`` anchors.
+            b: Reset ``b`` bold inline spans.
+            i: Reset ``i`` italic inline spans.
 
             event: Optional, unused. This exists for API compatibility with the
                 ``onClick`` functions.
         '''
+        # TODO: Why not reset everything always? YAGNI.
+        if b:
+            self.tag_configure('b', font=self._font(bold=True))
+        if i:
+            self.tag_configure('i', font=self._font(italic=True))
         for tag in self.tag_names():
             # a
             if a and tag == 'a' or tag.startswith('a::'):
@@ -1070,7 +1110,7 @@ class Notebook(ttk.Notebook, mixin.ContainerWidget):
         '''
         wtab = self.wtabs.get(idx, None)
         assert wtab is not None, f'Invalid Selection: {idx}'
-        return self.select(tab_id=str(wtab.widget))
+        self.select(tab_id=str(wtab.widget))
 
     def _tabScrollUp(self, event=None):
         keys = list(self.wtabs.keys())
@@ -1284,6 +1324,7 @@ class Tree(ttk.Treeview, mixin.SingleWidget):
 
         Should be reimplemented by subclasses that change the variable type.
         '''
+        assert isinstance(variable, varTree)
         return variable.get()
 
     def __tree_ls(self, parent: typing.Optional[str] = None) -> typing.Iterable[mixin.MixinWidget]:
