@@ -417,7 +417,7 @@ class TextEditor(FrameStateful):
         if cnt is None:
             cnt = 20 + random.choice(range(-10, 5))
         for r in range(cnt):
-            texts.append(f'Line {"%02d" % r}/{cnt} ')
+            texts.append(f'<b>Line</b> <i>{"%02d" % r}</i>/{cnt} ')
             if r % 2 == 0:
                 _txt = 'EVEN'
             else:
