@@ -248,7 +248,11 @@ class MixinWidget:
         of lower widgets, for example).
         '''
         assert isinstance(self, (tk.Widget, tk.Tk)), f'{self} is not a valid widget'
-        return self.nametowidget('.')
+        widget = self.nametowidget('.')
+        if __debug__:
+            from . import RootWindow  # For typechecking
+        assert isinstance(widget, RootWindow)
+        return widget
 
     def wroot_search(self) -> 'RootWindow':
         '''Alternative to `wroot` that crawls the widget tree.
@@ -281,8 +285,10 @@ class MixinWidget:
         Args:
             key: Optional. Defaults to the ``sequence`` itself. Useful to
                 support multiple bindings on the same sequence.
+            immediate: Passed to the upstream object, default to enabling the
+                binding on creation. This is the opposite from upstream.
 
-        All other arguments are passed to `model.Binding` object.
+        All other arguments are passed to the `model.Binding` object.
         '''
         name = key or sequence
         if name in self._bindings:
