@@ -1077,10 +1077,10 @@ class TextElement(abc.ABC):
 
 
 @dataclass
-class TextElement_span(TextElement):
-    '''Text Element: A text span, with optional tags.
+class TextElementInline(TextElement):
+    '''Text Element: A inline text span, with optional tags.
 
-    This is the most basic text element, just some string.
+    This is the most basic text element, just some inline string.
     It can optionally define one main tag, and other secondary tags to apply to
     the text.
 
@@ -1106,7 +1106,8 @@ class TextElement_span(TextElement):
         else:
             assert self.tags is None, 'Secondary tags without main tag'
         if '\n' in self.text:
-            warnings.warn('<span> should not have newlines, use <br/>', stacklevel=14)
+            tag_name = 'text' if self.tag is None else f'<{self.tag}>'
+            warnings.warn(f'{tag_name} should not have newlines, use <br/>', stacklevel=14)
         self.has_tags = True
 
     @property
@@ -1124,7 +1125,7 @@ class TextElement_span(TextElement):
 class TextElement_br(TextElement):
     '''Text Element: Line break.
 
-    This is equivalent to a `TextElement_span` with ``"\\n"`` as text.
+    This is equivalent to a `TextElementInline` with ``"\\n"`` as text.
     '''
     def __post_init__(self):
         self.text = '\n'
