@@ -85,8 +85,9 @@ class LTML(HTMLParser):
         Inherited from `HTMLParser.feed <html.parser.HTMLParser.feed>`
     '''
     TAGS_FULL = {
-        'a',
-        'span'
+        'a',  # anchor
+        'span',  # inline text
+        'b', 'i',  # inline text: bold, italic
     }
     '''Full Tags.
 
@@ -107,6 +108,15 @@ class LTML(HTMLParser):
     Like this: ``<tag />``
     '''
 
+    TAGS_MODEL = {
+        'a': model.TextElementInline,
+        'span': model.TextElementInline,
+        'b': model.TextElementInline,
+        'i': model.TextElementInline,
+        'br': model.TextElement_br,
+    }
+    '''Mapping tag names to its corresponding model class.'''
+
     cmdlist: typing.List[model.TextElement]
     '''Output command list.'''
 
@@ -116,6 +126,7 @@ class LTML(HTMLParser):
         self._act = tag_act
         # Asserts
         assert all(ts in self.TAGS_FULL for ts in self.TAGS_SIMPLE), 'All Simple Tags must be Full Tags'
+        assert all(t in self.TAGS_MODEL for t in [*self.TAGS_FULL, *self.TAGS_SE]), 'All Tags must have a model'
         # Parent initialization
         # - Should call `self.reset()` automatically
         super().__init__()
@@ -170,11 +181,7 @@ class LTML(HTMLParser):
         if tag not in self.TAGS_SE:
             raise ValueError(f'Invalid LTML: tag se {tag}')
         else:
-            what = None
-            if tag == 'br':
-                what = model.TextElement_br()
-            else:
-                raise NotImplementedError(f'Tag {tag}')  # Should never reach this
+            what = self.TAGS_MODEL[tag]()
             assert what is not None
             self.cmdlist.append(what)
 
@@ -186,7 +193,7 @@ class LTML(HTMLParser):
             raise ValueError(f'Unbalanced start/end tags: {self._ctag}/{tag}')
 
     def handle_data(self, string: str):
-        # TODO: Support chunked `feed`, do this on `handle_enddata`
+        # TODO: Support chunked `feed`, do this on `handle_endtag`
         main_tag = self._ctag
         tags = []
         data: typing.Mapping[str, str] = {}
@@ -197,13 +204,17 @@ class LTML(HTMLParser):
                 tags.append(f'{self._ctag}-{self._ctag_attrs.href}')
             if self._act:  # ACT
                 tags.append('%s::%d' % (main_tag, self._tctag[self._ctag] - 1))  # Start counting at 0
+            tag_model = self.TAGS_MODEL[main_tag]
+        else:
+            tag_model = model.TextElementInline
         if self._stags and main_tag in self.TAGS_SIMPLE and len(tags) == 0 and len(data) == 0:
             # Simplify simple tags
             main_tag = None
-        self.cmdlist.append(model.TextElement_span(string,
-                                                   tag=main_tag,
-                                                   tags=tags if len(tags) > 0 else None,
-                                                   data=data))
+        tag_obj = tag_model(string,
+                            tag=main_tag,
+                            tags=tags if len(tags) > 0 else None,
+                            data=data)
+        self.cmdlist.append(tag_obj)
 
     def parse(self, ltml: str) -> typing.Sequence[model.TextElement]:
         '''Helper function to parse a standalone string.
